@@ -7,6 +7,7 @@ from .base import (
     attribute,
     result,
     get_scenario_runner,
+    add_dynamic_arguments,
     DEFAULT_RESULTS_PATH,
     DEFAULT_RESULTS_SCENARIOS_PATH,
     DEFAULT_REPORTS_PATH,
@@ -28,6 +29,7 @@ __all__ = [
     "attribute",
     "result",
     "get_scenario_runner",
+    "add_dynamic_arguments",
     "DEFAULT_RESULTS_PATH",
     "DEFAULT_RESULTS_SCENARIOS_PATH",
     "DEFAULT_REPORTS_PATH",
